@@ -1,9 +1,10 @@
 class LabExtDataTable {
-    constructor(jquery, container, tunnel, columns, table_style, options = {}) {
+    constructor(jquery, container, tunnel, columns, columnDefs, table_style, options = {}) {
         this.$ = jquery;
         this.$container = container;
         this.tunnel = tunnel;
         this.columns = columns;
+        this.columnDefs = columnDefs;
         this.table_style = table_style;
         this.options = Object.assign({ deferRender: true, serverSide: true }, options);
         this.isInitComplete = false;
@@ -15,7 +16,7 @@ class LabExtDataTable {
             .attr({ "class": this.table_style })
             .css({ "width": "100%" })
             .appendTo(this.$container.empty());
-        $tbl.DataTable(Object.assign({ columns: this.columns.map(name => ({ title: name })), ajax: (data, callback, settings) => {
+        $tbl.DataTable(Object.assign({ columns: this.columns.map(name => ({ title: name })), columnDefs: this.columnDefs, ajax: (data, callback, settings) => {
                 // documentation in here: https://datatables.net/manual/server-side
                 let version = this.tunnel.send_msg(JSON.stringify({
                     type: "query",
