@@ -12,6 +12,8 @@ class LabExtDataTable {
   table_style: string;
   // list of column names
   columns: string[];
+  // list of column definitions
+  columnDefs?: object[];
   // init options for the DataTable plugin
   options: object;
 
@@ -21,12 +23,14 @@ class LabExtDataTable {
               container: JQuery<HTMLElement>,
               tunnel: Tunnel,
               columns: string[],
+              columnDefs: object[] | undefined,
               table_style: string,
               options: {} = {}) {
     this.$ = jquery;
     this.$container = container;
     this.tunnel = tunnel;
     this.columns = columns;
+    this.columnDefs = columnDefs;
 
     this.table_style = table_style;
     this.options = {
@@ -48,6 +52,7 @@ class LabExtDataTable {
 
     ($tbl as any).DataTable({
       columns: this.columns.map(name => ({title: name})),
+      columnDefs: this.columnDefs,
       ajax: (data: any, callback: any, settings: any) => {
         // documentation in here: https://datatables.net/manual/server-side
         let version = this.tunnel.send_msg(JSON.stringify({
