@@ -1,7 +1,7 @@
 import os
 from pathlib import Path
 from string import Template
-from typing import Type, List, TYPE_CHECKING, Optional, Callable
+from typing import Type, List, TYPE_CHECKING, Optional, Callable, Union
 from uuid import uuid4
 
 import ipywidgets.widgets as widgets
@@ -19,7 +19,7 @@ import labext.modules as M
 
 
 class DataTable(WidgetWrapper):
-    def __init__(self, df: 'DataFrame', table_class: str='display', table_id: Optional[str]=None, **kwargs):
+    def __init__(self, df: 'DataFrame', table_class: str='display', column_defs: Optional[Union[dict, List[dict]]]=None, table_id: Optional[str]=None, **kwargs):
         """Show the
 
         Parameters
@@ -28,6 +28,8 @@ class DataTable(WidgetWrapper):
             the data frame that we want to display
         table_class: str
             html classes for formatting the table's style: https://datatables.net/manual/styling/classes
+        column_defs: Union[dict, List[dict]]
+            custom definition for each column: https://datatables.net/reference/option/columnDefs
         table_id: Optional[str]
             id of the table, manually giving the table an id helps reducing number of instances in the client
             as we store this data table in the client side to reduce the
@@ -37,6 +39,11 @@ class DataTable(WidgetWrapper):
         """
         self.df = df
         self.table_class = table_class
+
+        if column_defs is not None and not isinstance(column_defs, list):
+            column_defs = [column_defs] * len(self.df.columns)
+        self.column_defs = column_defs
+
         self.table_id = table_id or str(uuid4())
         self.options = kwargs
 
@@ -83,7 +90,7 @@ class DataTable(WidgetWrapper):
                     let tunnel = window.IPyCallback.get("$tunnelId");
                     let model = new LabExtDataTable(
                         jquery, el, tunnel,
-                        $columns, "$table_class", $options
+                        $columns, $columnDefs, "$table_class", $options
                     );
                     model.render();
                     window.$container.DataTable.set("$tableId", model);
@@ -96,6 +103,7 @@ class DataTable(WidgetWrapper):
                                 tableId=self.table_id,
                                 tunnelId=self.tunnel.tunnel_id,
                                 columns=ujson.dumps(self.df.columns.tolist()),
+                                columnDefs=ujson.dumps(self.column_defs) if self.column_defs is not None else 'undefined',
                                 table_class=self.table_class,
                                 options=ujson.dumps(self.options))
 
